﻿using System.Collections.Specialized;
using Template.Business.Enumerations;

namespace Template.Business.ComponentInterfaces
{
    /// <summary>
    /// Component used for navigating in the webapp
    /// </summary>
    public interface INavigationComponent
    {
        /// <summary>
        /// Navigates to a page uniquely identified by the page identifier, passing the specifief querystring parameters.
        /// </summary>
        /// <param name="pageIdentifier">The page identifier.</param>
        /// <param name="queryString">The query string.</param>
        void NavigateTo(PageIdentifier pageIdentifier, NameValueCollection queryString);

        /// <summary>
        /// Navigates to a page uniquely identified by the page identifier, passing the specifief querystring as a string.
        /// </summary>
        /// <param name="pageIdentifier">The page identifier.</param>
        /// <param name="queryParams">The query string parameterss, even params = identifiers, odd params = values.</param>
        void NavigateTo(PageIdentifier pageIdentifier, params string[] queryParams);

        /// <summary>
        /// Gets the URL filepath.
        /// </summary>
        /// <param name="pageIdentifier">The page identifier.</param>
        /// <param name="queryParams">The query string parameters, even params = identifiers, odd params = values.</param>
        /// <returns></returns>
        string GetUrl(PageIdentifier pageIdentifier, params string[] queryParams);

        /// <summary>
        /// Gets the URL for the specified control.
        /// </summary>
        /// <param name="identifier">The control identifier.</param>
        /// <returns></returns>
        string GetUrl(ControlIdentifier identifier);

        /// <summary>
        /// Refreshes the current page.
        /// </summary>
        void Refresh();

        /// <summary>
        /// Navigates to a specified page, stocking the current Url in the querystring, so we can return later, calling "ReturnToCaller".
        /// </summary>
        /// <param name="pageIdentifier">The page identifier.</param>
        void NavigateAndReturnTo(PageIdentifier pageIdentifier);

        /// <summary>
        /// Gets a previously stocked Url from the querystring, and navigates to it.
        /// </summary>
        bool ReturnToCaller();
    }
}