﻿using System.Collections;
using System.Collections.Generic;
using System.Linq;
using Template.Business.ComponentInterfaces;
using Template.Business.DomainObjects;
using Template.Data.DataAccess;
using Template.Data.Entities;
using Template.Data.Interfaces;

namespace Template.Business.Components
{
    public class ReferenceDataComponent : IReferenceDataComponent
    {


        #region External Dependencies

        private object _ReferenceDataAccess;
        private IReferenceDataAccess ReferenceDataAccess
        {
            get
            {
                if (!(_ReferenceDataAccess is IReferenceDataAccess))
                    _ReferenceDataAccess = new ReferenceDataAccess();
                return (IReferenceDataAccess)_ReferenceDataAccess;
            }
        }

        #endregion

        #region Constructors

        /// <summary>
        /// Initializes a new instance of the <see cref="ReferenceDataComponent"/> class.
        /// </summary>
        public ReferenceDataComponent() : this(null)
        {}

        /// <summary>
        /// Initializes a new instance of the <see cref="ReferenceDataComponent"/> class.
        /// Used for Mocking/DI
        /// </summary>
        /// <param name="referenceDataAccess">The reference data access.</param>
        internal ReferenceDataComponent(IReferenceDataAccess referenceDataAccess)
        {
            this._ReferenceDataAccess = referenceDataAccess;
        }

        #endregion


        #region IReferenceDataComponent Members

        /// <summary>
        /// Gets the available languages.
        /// </summary>
        /// <returns></returns>
        public IList<Language> GetAvailableLanguages()
        {
            List<Language> result = new List<Language>();
            foreach (LanguageEntity entity in this.ReferenceDataAccess.GetAvailableLanguages())
                result.Add(new Language(entity));
            return result;

        }

        /// <summary>
        /// Gets the language by localeID.
        /// </summary>
        /// <param name="localeId">The localeId.</param>
        /// <returns></returns>
        public Language GetLanguageByLocaleID(int localeId)
        {
            var result = from l in GetAvailableLanguages()
                         where l.LocaleId == localeId
                         select l;
            return result.FirstOrDefault();
        }

        #endregion
    }
}