﻿using System;
using System.Collections.Specialized;
using Template.Business.ComponentInterfaces;
using Template.Business.Enumerations;
using Template.Business.Helpers;
using Template.Business.ViewInterfaces;

namespace Template.Business.Presenters
{
    public class TestPage1Presenter : BasePresenter<ITestPage1>
    {

        /// <summary>
        /// Initializes a new instance of the <see cref="TestPage1Presenter"/> class.
        /// </summary>
        /// <param name="view">The view.</param>
        public TestPage1Presenter(ITestPage1 view)
            : base(view)
        {
        }

        /// <summary>
        /// Subscribes the view to events.
        /// </summary>
        protected override void SubscribeViewToEvents()
        {
            View.ContinueClicked += new EventHandler(View_ContinueClicked);
        }


        internal void View_ContinueClicked(object sender, EventArgs e)
        {
            SessionComponent.User = View.UserName;
            int LocaleId = View.SelectedLanguageId;
            NavigationComponent.NavigateTo(PageIdentifier.TestPage2, 
                QueryStringParameter.Language.ToString(), LocaleId.ToString());
        }

        /// <summary>
        /// Called when the view is loaded.
        /// </summary>
        /// <param name="sender">The sender.</param>
        /// <param name="e">The <see cref="System.EventArgs"/> instance containing the event data.</param>
        protected override void OnViewLoad(object sender, EventArgs e)
        {
            if (!IsPostBack)
                LoadViewFromModel();
        }

        /// <summary>
        /// Method that should be called to bind the model to the view
        /// </summary>
        protected override void LoadViewFromModel()
        {
            View.Languages = ReferenceDataComponent.GetAvailableLanguages();
        }
    }

 
}