﻿using System;
using Template.Business.ComponentInterfaces;
using Template.Business.DomainObjects;
using Template.Business.Enumerations;
using Template.Business.Helpers;
using Template.Business.ViewInterfaces;

namespace Template.Business.Presenters
{
    public class TestPage2Presenter : BasePresenter<ITestPage2>
    {
        /// <summary>
        /// Initializes a new instance of the <see cref="TestPage2Presenter"/> class.
        /// </summary>
        /// <param name="view">The view.</param>
        public TestPage2Presenter(ITestPage2 view)
            : base(view)
        {
        }


        /// <summary>
        /// Subscribes the view to events.
        /// This method has to be inmplemented in every presenter class
        /// </summary>
        protected override void SubscribeViewToEvents()
        {
            View.BackButtonClicked += new EventHandler(View_BackButtonClicked);
            View.ToggleLanguageButtonClicked += new EventHandler(View_ToggleLanguageButtonClicked);
            View.ToggleUserButtonClicked += new EventHandler(View_ToggleUserButtonClicked);
        }

        /// <summary>
        /// Handles the ToggleUserButtonClicked event of the View control.
        /// </summary>
        /// <param name="sender">The source of the event.</param>
        /// <param name="e">The <see cref="System.EventArgs"/> instance containing the event data.</param>
        void View_ToggleUserButtonClicked(object sender, EventArgs e)
        {
            View.UserVisible = !View.UserVisible;
        }

        /// <summary>
        /// Handles the ToggleLanguageButtonClicked event of the View control.
        /// </summary>
        /// <param name="sender">The source of the event.</param>
        /// <param name="e">The <see cref="System.EventArgs"/> instance containing the event data.</param>
        void View_ToggleLanguageButtonClicked(object sender, EventArgs e)
        {
            View.LanguageVisible = !View.LanguageVisible;
        }

        /// <summary>
        /// Handles the BackButtonClicked event of the _view control.
        /// </summary>
        /// <param name="sender">The source of the event.</param>
        /// <param name="e">The <see cref="System.EventArgs"/> instance containing the event data.</param>
        void View_BackButtonClicked(object sender, EventArgs e)
        {
            NavigationComponent.NavigateTo(PageIdentifier.TestPage1);
        }

        /// <summary>
        /// Called when the view is loaded.
        /// </summary>
        /// <param name="sender">The sender.</param>
        /// <param name="e">The <see cref="System.EventArgs"/> instance containing the event data.</param>
        protected override void OnViewLoad(object sender, EventArgs e)
        {
            if (!IsPostBack)
            {
                View.UserVisible = false;
                View.LanguageVisible = false;
            }
            else
            {
                View.UserVisible = View.UserVisible;
                View.LanguageVisible = View.LanguageVisible;
            }
        }


        /// <summary>
        /// Method that should be called to bind the model to the view
        /// </summary>
        protected override void LoadViewFromModel()
        {
        }
    }
}