﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using Microsoft.VisualStudio.TestTools.UnitTesting;
using Moq;
using Template.Business;
using Template.Business.ComponentInterfaces;
using Template.Business.Enumerations;
using Template.Business.Presenters;
using Template.Business.ViewInterfaces;

namespace Template.Test.PresenterTests
{
    [TestClass]
    public class TestPage1PresenterTest
    {
        private ISessionComponent session;
        private Mock<INavigationComponent> navigation;

        [TestInitialize]
        public void sSetup()
        {
            ServiceLocator.Instance().InitializeForUnitTesting();
            //register a stubbed session in the container
            session = new StubSession();
            ServiceLocator.Instance().RegisterInstance<ISessionComponent>(session);
            //register a mocked navigation component in the container
            navigation = new Mock<INavigationComponent>();
            ServiceLocator.Instance().RegisterInstance<INavigationComponent>(navigation.Object);

        }

        [TestMethod]
        public void Should_navigate_to_page2_on_ContinueClick_Event_Raised_On_View()
        {
            //set expectation that we will navigate to a certain page
            bool isCalled = false;
            navigation.Expect(n => n.NavigateTo(PageIdentifier.TestPage2, It.IsAny<string[]>())).Callback(() => isCalled = true);
            //initiate the ContinueClicked via the event on the view - a bit awkward code to initiate the event
            var mockedView = new Mock<ITestPage1>();
            MockedEvent<EventArgs> ev = mockedView.CreateEventHandler();
            mockedView.Object.ContinueClicked += ev;
            var presenter = new TestPage1Presenter(mockedView.Object);
            ev.Raise(EventArgs.Empty);
            Assert.IsTrue(isCalled);
        }

        [TestMethod]
        public void Should_navigate_to_page2_on_ContinueClicked_method()
        {
            //set expectation that we will navigate to a certain page
            bool isCalled = false;
            navigation.Expect(n => n.NavigateTo(PageIdentifier.TestPage2, It.IsAny<string[]>())).Callback(() => isCalled = true);
            //directly call the continue clicked method on the presenter ...it should be 'internal' to make this work
            var mockedView = new Mock<ITestPage1>();
            var presenter = new TestPage1Presenter(mockedView.Object);
            presenter.View_ContinueClicked(null,null);
            Assert.IsTrue(isCalled);
        }

    }
}
